summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authoravi@chromium.org <avi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-11-16 21:36:16 +0000
committeravi@chromium.org <avi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-11-16 21:36:16 +0000
commit0da6b4455b596572e379c150aa5babf8d6364833 (patch)
tree8d75818184e4b26ecefe915d99e17399079afb32
parentea1ba32fb09f3c84768c1272b79b8519aadee0df (diff)
downloadchromium_src-0da6b4455b596572e379c150aa5babf8d6364833.zip
chromium_src-0da6b4455b596572e379c150aa5babf8d6364833.tar.gz
chromium_src-0da6b4455b596572e379c150aa5babf8d6364833.tar.bz2
Add OVERRIDE to webkit/.
BUG=104314 TEST=no change Review URL: http://codereview.chromium.org/8539047 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@110357 0039d316-1c4b-4281-b951-d872f2087c98
-rw-r--r--webkit/appcache/appcache_disk_cache.h7
-rw-r--r--webkit/appcache/appcache_frontend_impl.h14
-rw-r--r--webkit/appcache/appcache_host.h6
-rw-r--r--webkit/appcache/appcache_interceptor.h12
-rw-r--r--webkit/appcache/appcache_quota_client.h2
-rw-r--r--webkit/appcache/appcache_response.h4
-rw-r--r--webkit/appcache/appcache_storage_impl.h39
-rw-r--r--webkit/appcache/appcache_update_job.h17
-rw-r--r--webkit/appcache/appcache_url_request_job.h23
-rw-r--r--webkit/appcache/mock_appcache_policy.h5
-rw-r--r--webkit/appcache/mock_appcache_service.h7
-rw-r--r--webkit/appcache/mock_appcache_storage.h37
-rw-r--r--webkit/blob/blob_url_request_job.h17
-rw-r--r--webkit/blob/view_blob_internals_job.h9
-rw-r--r--webkit/database/database_quota_client.h2
-rw-r--r--webkit/fileapi/file_system_dir_url_request_job.h12
-rw-r--r--webkit/fileapi/file_system_url_request_job.h20
-rw-r--r--webkit/fileapi/sandbox_mount_point_provider.h12
-rw-r--r--webkit/glue/media/buffered_data_source.h30
-rw-r--r--webkit/glue/media/simple_data_source.h26
-rw-r--r--webkit/glue/media/web_data_source_factory.h6
-rw-r--r--webkit/glue/webmediaplayer_impl.h2
-rw-r--r--webkit/plugins/npapi/plugin_stream_url.h24
-rw-r--r--webkit/plugins/npapi/test/plugin_arguments_test.h7
-rw-r--r--webkit/plugins/npapi/test/plugin_delete_plugin_in_deallocate_test.h5
-rw-r--r--webkit/plugins/npapi/test/plugin_delete_plugin_in_stream_test.h7
-rw-r--r--webkit/plugins/npapi/test/plugin_get_javascript_url2_test.h17
-rw-r--r--webkit/plugins/npapi/test/plugin_get_javascript_url_test.h17
-rw-r--r--webkit/plugins/npapi/test/plugin_geturl_test.h20
-rw-r--r--webkit/plugins/npapi/test/plugin_javascript_open_popup.h7
-rw-r--r--webkit/plugins/npapi/test/plugin_new_fails_test.h5
-rw-r--r--webkit/plugins/npapi/test/plugin_npobject_identity_test.h2
-rw-r--r--webkit/plugins/npapi/test/plugin_npobject_lifetime_test.h13
-rw-r--r--webkit/plugins/npapi/test/plugin_npobject_proxy_test.h4
-rw-r--r--webkit/plugins/npapi/test/plugin_private_test.h5
-rw-r--r--webkit/plugins/npapi/test/plugin_schedule_timer_test.h5
-rw-r--r--webkit/plugins/npapi/test/plugin_setup_test.h4
-rw-r--r--webkit/plugins/npapi/test/plugin_thread_async_call_test.h6
-rw-r--r--webkit/plugins/npapi/test/plugin_window_size_test.h5
-rw-r--r--webkit/plugins/npapi/test/plugin_windowless_test.h4
-rw-r--r--webkit/plugins/npapi/webplugin_delegate_impl.h37
-rw-r--r--webkit/plugins/npapi/webplugin_impl.h39
-rw-r--r--webkit/quota/mock_special_storage_policy.h11
-rw-r--r--webkit/support/simple_database_system.h7
-rw-r--r--webkit/support/test_webplugin_page_delegate.h18
-rw-r--r--webkit/tools/test_shell/accessibility_ui_element.h6
-rw-r--r--webkit/tools/test_shell/simple_file_writer.h6
-rw-r--r--webkit/tools/test_shell/test_shell_request_context.h2
-rw-r--r--webkit/tools/test_shell/test_shell_test.h8
-rw-r--r--webkit/tools/test_shell/test_shell_webmimeregistry_impl.h5
-rw-r--r--webkit/tools/test_shell/test_webview_delegate.h14
51 files changed, 342 insertions, 277 deletions
diff --git a/webkit/appcache/appcache_disk_cache.h b/webkit/appcache/appcache_disk_cache.h
index a4aa551..f5259c2 100644
--- a/webkit/appcache/appcache_disk_cache.h
+++ b/webkit/appcache/appcache_disk_cache.h
@@ -38,10 +38,11 @@ class APPCACHE_EXPORT AppCacheDiskCache
bool is_disabled() const { return is_disabled_; }
virtual int CreateEntry(int64 key, Entry** entry,
- net::OldCompletionCallback* callback);
+ net::OldCompletionCallback* callback) OVERRIDE;
virtual int OpenEntry(int64 key, Entry** entry,
- net::OldCompletionCallback* callback);
- virtual int DoomEntry(int64 key, net::OldCompletionCallback* callback);
+ net::OldCompletionCallback* callback) OVERRIDE;
+ virtual int DoomEntry(int64 key,
+ net::OldCompletionCallback* callback) OVERRIDE;
private:
class EntryImpl;
diff --git a/webkit/appcache/appcache_frontend_impl.h b/webkit/appcache/appcache_frontend_impl.h
index ce37d26..7c28eab 100644
--- a/webkit/appcache/appcache_frontend_impl.h
+++ b/webkit/appcache/appcache_frontend_impl.h
@@ -15,19 +15,19 @@ namespace appcache {
class APPCACHE_EXPORT AppCacheFrontendImpl : public AppCacheFrontend {
public:
virtual void OnCacheSelected(
- int host_id, const appcache::AppCacheInfo& info);
+ int host_id, const appcache::AppCacheInfo& info) OVERRIDE;
virtual void OnStatusChanged(const std::vector<int>& host_ids,
- Status status);
+ Status status) OVERRIDE;
virtual void OnEventRaised(const std::vector<int>& host_ids,
- EventID event_id);
+ EventID event_id) OVERRIDE;
virtual void OnProgressEventRaised(const std::vector<int>& host_ids,
const GURL& url,
- int num_total, int num_complete);
+ int num_total, int num_complete) OVERRIDE;
virtual void OnErrorEventRaised(const std::vector<int>& host_ids,
- const std::string& message);
+ const std::string& message) OVERRIDE;
virtual void OnLogMessage(int host_id, LogLevel log_level,
- const std::string& message);
- virtual void OnContentBlocked(int host_id, const GURL& manifest_url);
+ const std::string& message) OVERRIDE;
+ virtual void OnContentBlocked(int host_id, const GURL& manifest_url) OVERRIDE;
};
} // namespace
diff --git a/webkit/appcache/appcache_host.h b/webkit/appcache/appcache_host.h
index 25d46f5..2ea022b 100644
--- a/webkit/appcache/appcache_host.h
+++ b/webkit/appcache/appcache_host.h
@@ -158,9 +158,9 @@ class APPCACHE_EXPORT AppCacheHost : public AppCacheStorage::Delegate,
void AssociateCacheHelper(AppCache* cache, const GURL& manifest_url);
// AppCacheStorage::Delegate impl
- virtual void OnCacheLoaded(AppCache* cache, int64 cache_id);
+ virtual void OnCacheLoaded(AppCache* cache, int64 cache_id) OVERRIDE;
virtual void OnGroupLoaded(AppCacheGroup* group,
- const GURL& manifest_url);
+ const GURL& manifest_url) OVERRIDE;
void FinishCacheSelection(AppCache* cache, AppCacheGroup* group);
void DoPendingGetStatus();
@@ -170,7 +170,7 @@ class APPCACHE_EXPORT AppCacheHost : public AppCacheStorage::Delegate,
void ObserveGroupBeingUpdated(AppCacheGroup* group);
// AppCacheGroup::UpdateObserver methods.
- virtual void OnUpdateComplete(AppCacheGroup* group);
+ virtual void OnUpdateComplete(AppCacheGroup* group) OVERRIDE;
// Returns true if this host is for a dedicated worker context.
bool is_for_dedicated_worker() const {
diff --git a/webkit/appcache/appcache_quota_client.h b/webkit/appcache/appcache_quota_client.h
index e394973..20c0f0d 100644
--- a/webkit/appcache/appcache_quota_client.h
+++ b/webkit/appcache/appcache_quota_client.h
@@ -38,7 +38,7 @@ class AppCacheQuotaClient : public quota::QuotaClient {
// QuotaClient method overrides
virtual ID id() const OVERRIDE;
- virtual void OnQuotaManagerDestroyed();
+ virtual void OnQuotaManagerDestroyed() OVERRIDE;
virtual void GetOriginUsage(const GURL& origin,
quota::StorageType type,
const GetUsageCallback& callback) OVERRIDE;
diff --git a/webkit/appcache/appcache_response.h b/webkit/appcache/appcache_response.h
index 7119d6e..e4c5d6a 100644
--- a/webkit/appcache/appcache_response.h
+++ b/webkit/appcache/appcache_response.h
@@ -193,7 +193,7 @@ class APPCACHE_EXPORT AppCacheResponseReader : public AppCacheResponseIO {
int64 group_id,
AppCacheDiskCacheInterface* disk_cache);
- virtual void OnIOComplete(int result);
+ virtual void OnIOComplete(int result) OVERRIDE;
void ContinueReadInfo();
void ContinueReadData();
void OpenEntryIfNeededAndContinue();
@@ -256,7 +256,7 @@ class APPCACHE_EXPORT AppCacheResponseWriter : public AppCacheResponseIO {
int64 group_id,
AppCacheDiskCacheInterface* disk_cache);
- virtual void OnIOComplete(int result);
+ virtual void OnIOComplete(int result) OVERRIDE;
void ContinueWriteInfo();
void ContinueWriteData();
void CreateEntryIfNeededAndContinue();
diff --git a/webkit/appcache/appcache_storage_impl.h b/webkit/appcache/appcache_storage_impl.h
index 3c12b6d..f54295a 100644
--- a/webkit/appcache/appcache_storage_impl.h
+++ b/webkit/appcache/appcache_storage_impl.h
@@ -35,28 +35,33 @@ class AppCacheStorageImpl : public AppCacheStorage {
bool is_disabled() const { return is_disabled_; }
// AppCacheStorage methods, see the base class for doc comments.
- virtual void GetAllInfo(Delegate* delegate);
- virtual void LoadCache(int64 id, Delegate* delegate);
- virtual void LoadOrCreateGroup(const GURL& manifest_url, Delegate* delegate);
- virtual void StoreGroupAndNewestCache(
- AppCacheGroup* group, AppCache* newest_cache, Delegate* delegate);
- virtual void FindResponseForMainRequest(
- const GURL& url, const GURL& preferred_manifest_url, Delegate* delegate);
+ virtual void GetAllInfo(Delegate* delegate) OVERRIDE;
+ virtual void LoadCache(int64 id, Delegate* delegate) OVERRIDE;
+ virtual void LoadOrCreateGroup(const GURL& manifest_url,
+ Delegate* delegate) OVERRIDE;
+ virtual void StoreGroupAndNewestCache(AppCacheGroup* group,
+ AppCache* newest_cache,
+ Delegate* delegate) OVERRIDE;
+ virtual void FindResponseForMainRequest(const GURL& url,
+ const GURL& preferred_manifest_url,
+ Delegate* delegate) OVERRIDE;
virtual void FindResponseForSubRequest(
AppCache* cache, const GURL& url,
AppCacheEntry* found_entry, AppCacheEntry* found_fallback_entry,
- bool* found_network_namespace);
- virtual void MarkEntryAsForeign(const GURL& entry_url, int64 cache_id);
- virtual void MakeGroupObsolete(AppCacheGroup* group, Delegate* delegate);
+ bool* found_network_namespace) OVERRIDE;
+ virtual void MarkEntryAsForeign(const GURL& entry_url,
+ int64 cache_id) OVERRIDE;
+ virtual void MakeGroupObsolete(AppCacheGroup* group,
+ Delegate* delegate) OVERRIDE;
virtual AppCacheResponseReader* CreateResponseReader(
- const GURL& manifest_url, int64 group_id, int64 response_id);
+ const GURL& manifest_url, int64 group_id, int64 response_id) OVERRIDE;
virtual AppCacheResponseWriter* CreateResponseWriter(
- const GURL& manifest_url, int64 group_id);
- virtual void DoomResponses(
- const GURL& manifest_url, const std::vector<int64>& response_ids);
- virtual void DeleteResponses(
- const GURL& manifest_url, const std::vector<int64>& response_ids);
- virtual void PurgeMemory();
+ const GURL& manifest_url, int64 group_id) OVERRIDE;
+ virtual void DoomResponses(const GURL& manifest_url,
+ const std::vector<int64>& response_ids) OVERRIDE;
+ virtual void DeleteResponses(const GURL& manifest_url,
+ const std::vector<int64>& response_ids) OVERRIDE;
+ virtual void PurgeMemory() OVERRIDE;
private:
friend class AppCacheStorageImplTest;
diff --git a/webkit/appcache/appcache_update_job.h b/webkit/appcache/appcache_update_job.h
index 6af14bd..cb19b24 100644
--- a/webkit/appcache/appcache_update_job.h
+++ b/webkit/appcache/appcache_update_job.h
@@ -122,9 +122,10 @@ class APPCACHE_EXPORT AppCacheUpdateJob : public AppCacheStorage::Delegate,
// URLRequest::Delegate overrides
virtual void OnReceivedRedirect(net::URLRequest* request,
const GURL& new_url,
- bool* defer_redirect);
- virtual void OnResponseStarted(net::URLRequest* request);
- virtual void OnReadCompleted(net::URLRequest* request, int bytes_read);
+ bool* defer_redirect) OVERRIDE;
+ virtual void OnResponseStarted(net::URLRequest* request) OVERRIDE;
+ virtual void OnReadCompleted(net::URLRequest* request,
+ int bytes_read) OVERRIDE;
void AddConditionalHeaders(const net::HttpResponseHeaders* headers);
void OnWriteComplete(int result);
@@ -150,16 +151,16 @@ class APPCACHE_EXPORT AppCacheUpdateJob : public AppCacheStorage::Delegate,
// Methods for AppCacheStorage::Delegate.
virtual void OnResponseInfoLoaded(AppCacheResponseInfo* response_info,
- int64 response_id);
+ int64 response_id) OVERRIDE;
virtual void OnGroupAndNewestCacheStored(AppCacheGroup* group,
AppCache* newest_cache,
bool success,
- bool would_exceed_quota);
- virtual void OnGroupMadeObsolete(AppCacheGroup* group, bool success);
+ bool would_exceed_quota) OVERRIDE;
+ virtual void OnGroupMadeObsolete(AppCacheGroup* group, bool success) OVERRIDE;
// Methods for AppCacheHost::Observer.
- virtual void OnCacheSelectionComplete(AppCacheHost* host) {} // N/A
- virtual void OnDestructionImminent(AppCacheHost* host);
+ virtual void OnCacheSelectionComplete(AppCacheHost* host) OVERRIDE {} // N/A
+ virtual void OnDestructionImminent(AppCacheHost* host) OVERRIDE;
void HandleCacheFailure(const std::string& error_message);
diff --git a/webkit/appcache/appcache_url_request_job.h b/webkit/appcache/appcache_url_request_job.h
index 553bbab..271a777 100644
--- a/webkit/appcache/appcache_url_request_job.h
+++ b/webkit/appcache/appcache_url_request_job.h
@@ -60,7 +60,7 @@ class APPCACHE_EXPORT AppCacheURLRequestJob : public net::URLRequestJob,
// net::URLRequestJob's Kill method is made public so the users of this
// class in the appcache namespace can call it.
- virtual void Kill();
+ virtual void Kill() OVERRIDE;
// Returns true if the job has been started by the net library.
bool has_been_started() const {
@@ -98,7 +98,7 @@ class APPCACHE_EXPORT AppCacheURLRequestJob : public net::URLRequestJob,
// AppCacheStorage::Delegate methods
virtual void OnResponseInfoLoaded(
- AppCacheResponseInfo* response_info, int64 response_id);
+ AppCacheResponseInfo* response_info, int64 response_id) OVERRIDE;
const net::HttpResponseInfo* http_info() const;
bool is_range_request() const { return range_requested_.IsValid(); }
@@ -108,19 +108,22 @@ class APPCACHE_EXPORT AppCacheURLRequestJob : public net::URLRequestJob,
void OnReadComplete(int result);
// net::URLRequestJob methods, see url_request_job.h for doc comments
- virtual void Start();
- virtual net::LoadState GetLoadState() const;
- virtual bool GetCharset(std::string* charset);
- virtual void GetResponseInfo(net::HttpResponseInfo* info);
- virtual bool ReadRawData(net::IOBuffer* buf, int buf_size, int *bytes_read);
+ virtual void Start() OVERRIDE;
+ virtual net::LoadState GetLoadState() const OVERRIDE;
+ virtual bool GetCharset(std::string* charset) OVERRIDE;
+ virtual void GetResponseInfo(net::HttpResponseInfo* info) OVERRIDE;
+ virtual bool ReadRawData(net::IOBuffer* buf,
+ int buf_size,
+ int *bytes_read) OVERRIDE;
// Sets extra request headers for Job types that support request headers.
// This is how we get informed of range-requests.
- virtual void SetExtraRequestHeaders(const net::HttpRequestHeaders& headers);
+ virtual void SetExtraRequestHeaders(
+ const net::HttpRequestHeaders& headers) OVERRIDE;
// FilterContext methods
- virtual bool GetMimeType(std::string* mime_type) const;
- virtual int GetResponseCode() const;
+ virtual bool GetMimeType(std::string* mime_type) const OVERRIDE;
+ virtual int GetResponseCode() const OVERRIDE;
AppCacheStorage* storage_;
bool has_been_started_;
diff --git a/webkit/appcache/mock_appcache_policy.h b/webkit/appcache/mock_appcache_policy.h
index 2fb962d..5c70002 100644
--- a/webkit/appcache/mock_appcache_policy.h
+++ b/webkit/appcache/mock_appcache_policy.h
@@ -5,6 +5,7 @@
#ifndef WEBKIT_APPCACHE_MOCK_APPCACHE_POLICY_H_
#define WEBKIT_APPCACHE_MOCK_APPCACHE_POLICY_H_
+#include "base/compiler_specific.h"
#include "googleurl/src/gurl.h"
#include "webkit/appcache/appcache_policy.h"
@@ -16,9 +17,9 @@ class MockAppCachePolicy : public AppCachePolicy {
virtual ~MockAppCachePolicy();
virtual bool CanLoadAppCache(const GURL& manifest_url,
- const GURL& first_party);
+ const GURL& first_party) OVERRIDE;
virtual bool CanCreateAppCache(const GURL& manifest_url,
- const GURL& first_party);
+ const GURL& first_party) OVERRIDE;
bool can_load_return_value_;
bool can_create_return_value_;
diff --git a/webkit/appcache/mock_appcache_service.h b/webkit/appcache/mock_appcache_service.h
index e828504..f803c28 100644
--- a/webkit/appcache/mock_appcache_service.h
+++ b/webkit/appcache/mock_appcache_service.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2009 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -24,8 +24,9 @@ class MockAppCacheService : public AppCacheService {
// Just returns a canned completion code without actually
// removing groups and caches in our mock storage instance.
- virtual void DeleteAppCachesForOrigin(const GURL& origin,
- net::OldCompletionCallback* callback);
+ virtual void DeleteAppCachesForOrigin(
+ const GURL& origin,
+ net::OldCompletionCallback* callback) OVERRIDE;
void set_quota_manager_proxy(quota::QuotaManagerProxy* proxy) {
quota_manager_proxy_ = proxy;
diff --git a/webkit/appcache/mock_appcache_storage.h b/webkit/appcache/mock_appcache_storage.h
index c3b88b6..424a0f9 100644
--- a/webkit/appcache/mock_appcache_storage.h
+++ b/webkit/appcache/mock_appcache_storage.h
@@ -31,28 +31,35 @@ class MockAppCacheStorage : public AppCacheStorage {
explicit MockAppCacheStorage(AppCacheService* service);
virtual ~MockAppCacheStorage();
- virtual void GetAllInfo(Delegate* delegate);
- virtual void LoadCache(int64 id, Delegate* delegate);
- virtual void LoadOrCreateGroup(const GURL& manifest_url, Delegate* delegate);
- virtual void StoreGroupAndNewestCache(
- AppCacheGroup* group, AppCache* newest_cache, Delegate* delegate);
- virtual void FindResponseForMainRequest(
- const GURL& url, const GURL& preferred_manifest_url, Delegate* delegate);
+ virtual void GetAllInfo(Delegate* delegate) OVERRIDE;
+ virtual void LoadCache(int64 id, Delegate* delegate) OVERRIDE;
+ virtual void LoadOrCreateGroup(const GURL& manifest_url,
+ Delegate* delegate) OVERRIDE;
+ virtual void StoreGroupAndNewestCache(AppCacheGroup* group,
+ AppCache* newest_cache,
+ Delegate* delegate) OVERRIDE;
+ virtual void FindResponseForMainRequest(const GURL& url,
+ const GURL& preferred_manifest_url,
+ Delegate* delegate) OVERRIDE;
virtual void FindResponseForSubRequest(
AppCache* cache, const GURL& url,
AppCacheEntry* found_entry, AppCacheEntry* found_fallback_entry,
- bool * found_network_namespace);
- virtual void MarkEntryAsForeign(const GURL& entry_url, int64 cache_id);
- virtual void MakeGroupObsolete(AppCacheGroup* group, Delegate* delegate);
+ bool * found_network_namespace) OVERRIDE;
+ virtual void MarkEntryAsForeign(const GURL& entry_url,
+ int64 cache_id) OVERRIDE;
+ virtual void MakeGroupObsolete(AppCacheGroup* group,
+ Delegate* delegate) OVERRIDE;
virtual AppCacheResponseReader* CreateResponseReader(
- const GURL& manifest_url, int64 group_id, int64 response_id);
+ const GURL& manifest_url, int64 group_id, int64 response_id) OVERRIDE;
virtual AppCacheResponseWriter* CreateResponseWriter(
- const GURL& manifest_url, int64 group_id);
+ const GURL& manifest_url, int64 group_id) OVERRIDE;
virtual void DoomResponses(
- const GURL& manifest_url, const std::vector<int64>& response_ids);
+ const GURL& manifest_url,
+ const std::vector<int64>& response_ids) OVERRIDE;
virtual void DeleteResponses(
- const GURL& manifest_url, const std::vector<int64>& response_ids);
- virtual void PurgeMemory() {}
+ const GURL& manifest_url,
+ const std::vector<int64>& response_ids) OVERRIDE;
+ virtual void PurgeMemory() OVERRIDE {}
private:
friend class AppCacheRequestHandlerTest;
diff --git a/webkit/blob/blob_url_request_job.h b/webkit/blob/blob_url_request_job.h
index 6db31ad..00cf0c6 100644
--- a/webkit/blob/blob_url_request_job.h
+++ b/webkit/blob/blob_url_request_job.h
@@ -34,13 +34,16 @@ class BLOB_EXPORT BlobURLRequestJob : public net::URLRequestJob {
virtual ~BlobURLRequestJob();
// net::URLRequestJob methods.
- virtual void Start();
- virtual void Kill();
- virtual bool ReadRawData(net::IOBuffer* buf, int buf_size, int* bytes_read);
- virtual bool GetMimeType(std::string* mime_type) const;
- virtual void GetResponseInfo(net::HttpResponseInfo* info);
- virtual int GetResponseCode() const;
- virtual void SetExtraRequestHeaders(const net::HttpRequestHeaders& headers);
+ virtual void Start() OVERRIDE;
+ virtual void Kill() OVERRIDE;
+ virtual bool ReadRawData(net::IOBuffer* buf,
+ int buf_size,
+ int* bytes_read) OVERRIDE;
+ virtual bool GetMimeType(std::string* mime_type) const OVERRIDE;
+ virtual void GetResponseInfo(net::HttpResponseInfo* info) OVERRIDE;
+ virtual int GetResponseCode() const OVERRIDE;
+ virtual void SetExtraRequestHeaders(
+ const net::HttpRequestHeaders& headers) OVERRIDE;
private:
void CloseStream();
diff --git a/webkit/blob/view_blob_internals_job.h b/webkit/blob/view_blob_internals_job.h
index a56da72..f88f310 100644
--- a/webkit/blob/view_blob_internals_job.h
+++ b/webkit/blob/view_blob_internals_job.h
@@ -27,12 +27,13 @@ class BLOB_EXPORT ViewBlobInternalsJob : public net::URLRequestSimpleJob {
ViewBlobInternalsJob(net::URLRequest* request,
BlobStorageController* blob_storage_controller);
- virtual void Start();
+ virtual void Start() OVERRIDE;
virtual bool GetData(std::string* mime_type,
std::string* charset,
- std::string* data) const;
- virtual bool IsRedirectResponse(GURL* location, int* http_status_code);
- virtual void Kill();
+ std::string* data) const OVERRIDE;
+ virtual bool IsRedirectResponse(GURL* location,
+ int* http_status_code) OVERRIDE;
+ virtual void Kill() OVERRIDE;
private:
virtual ~ViewBlobInternalsJob();
diff --git a/webkit/database/database_quota_client.h b/webkit/database/database_quota_client.h
index b9fed41..ff36239 100644
--- a/webkit/database/database_quota_client.h
+++ b/webkit/database/database_quota_client.h
@@ -31,7 +31,7 @@ class DatabaseQuotaClient : public quota::QuotaClient,
// QuotaClient method overrides
virtual ID id() const OVERRIDE;
- virtual void OnQuotaManagerDestroyed();
+ virtual void OnQuotaManagerDestroyed() OVERRIDE;
virtual void GetOriginUsage(const GURL& origin_url,
quota::StorageType type,
const GetUsageCallback& callback) OVERRIDE;
diff --git a/webkit/fileapi/file_system_dir_url_request_job.h b/webkit/fileapi/file_system_dir_url_request_job.h
index 1b41438..058106f 100644
--- a/webkit/fileapi/file_system_dir_url_request_job.h
+++ b/webkit/fileapi/file_system_dir_url_request_job.h
@@ -30,13 +30,15 @@ class FileSystemDirURLRequestJob : public net::URLRequestJob {
scoped_refptr<base::MessageLoopProxy> file_thread_proxy);
// URLRequestJob methods:
- virtual void Start();
- virtual void Kill();
- virtual bool ReadRawData(net::IOBuffer* buf, int buf_size, int* bytes_read);
- virtual bool GetCharset(std::string* charset);
+ virtual void Start() OVERRIDE;
+ virtual void Kill() OVERRIDE;
+ virtual bool ReadRawData(net::IOBuffer* buf,
+ int buf_size,
+ int* bytes_read) OVERRIDE;
+ virtual bool GetCharset(std::string* charset) OVERRIDE;
// FilterContext methods (via URLRequestJob):
- virtual bool GetMimeType(std::string* mime_type) const;
+ virtual bool GetMimeType(std::string* mime_type) const OVERRIDE;
// TODO(adamk): Implement GetResponseInfo and GetResponseCode to simulate
// an HTTP response.
diff --git a/webkit/fileapi/file_system_url_request_job.h b/webkit/fileapi/file_system_url_request_job.h
index f405652..ad65392 100644
--- a/webkit/fileapi/file_system_url_request_job.h
+++ b/webkit/fileapi/file_system_url_request_job.h
@@ -35,16 +35,20 @@ class FileSystemURLRequestJob : public net::URLRequestJob {
scoped_refptr<base::MessageLoopProxy> file_thread_proxy);
// URLRequestJob methods:
- virtual void Start();
- virtual void Kill();
- virtual bool ReadRawData(net::IOBuffer* buf, int buf_size, int* bytes_read);
- virtual bool IsRedirectResponse(GURL* location, int* http_status_code);
- virtual void SetExtraRequestHeaders(const net::HttpRequestHeaders& headers);
- virtual void GetResponseInfo(net::HttpResponseInfo* info);
- virtual int GetResponseCode() const;
+ virtual void Start() OVERRIDE;
+ virtual void Kill() OVERRIDE;
+ virtual bool ReadRawData(net::IOBuffer* buf,
+ int buf_size,
+ int* bytes_read) OVERRIDE;
+ virtual bool IsRedirectResponse(GURL* location,
+ int* http_status_code) OVERRIDE;
+ virtual void SetExtraRequestHeaders(
+ const net::HttpRequestHeaders& headers) OVERRIDE;
+ virtual void GetResponseInfo(net::HttpResponseInfo* info) OVERRIDE;
+ virtual int GetResponseCode() const OVERRIDE;
// FilterContext methods (via URLRequestJob):
- virtual bool GetMimeType(std::string* mime_type) const;
+ virtual bool GetMimeType(std::string* mime_type) const OVERRIDE;
private:
class CallbackDispatcher;
diff --git a/webkit/fileapi/sandbox_mount_point_provider.h b/webkit/fileapi/sandbox_mount_point_provider.h
index 9696287..e23bafc 100644
--- a/webkit/fileapi/sandbox_mount_point_provider.h
+++ b/webkit/fileapi/sandbox_mount_point_provider.h
@@ -57,7 +57,7 @@ class SandboxMountPointProvider
// Checks if access to |virtual_path| is allowed from |origin_url|.
virtual bool IsAccessAllowed(const GURL& origin_url,
FileSystemType type,
- const FilePath& virtual_path);
+ const FilePath& virtual_path) OVERRIDE;
// Retrieves the root path for the given |origin_url| and |type|, and
// calls the given |callback| with the root path and name.
@@ -66,7 +66,7 @@ class SandboxMountPointProvider
const GURL& origin_url,
FileSystemType type,
bool create,
- const FileSystemPathManager::GetRootPathCallback& callback);
+ const FileSystemPathManager::GetRootPathCallback& callback) OVERRIDE;
// Like GetFileSystemRootPath, but synchronous, and can be called only while
// running on the file thread.
@@ -74,7 +74,7 @@ class SandboxMountPointProvider
const GURL& origin_url,
FileSystemType type,
const FilePath& unused,
- bool create);
+ bool create) OVERRIDE;
// The legacy [pre-obfuscation] FileSystem directory name, kept around for
// migration and migration testing.
@@ -89,9 +89,9 @@ class SandboxMountPointProvider
FilePath renamed_old_base_path() const;
// Checks if a given |name| contains any restricted names/chars in it.
- virtual bool IsRestrictedFileName(const FilePath& filename) const;
+ virtual bool IsRestrictedFileName(const FilePath& filename) const OVERRIDE;
- virtual std::vector<FilePath> GetRootDirectories() const;
+ virtual std::vector<FilePath> GetRootDirectories() const OVERRIDE;
// Returns an origin enumerator of this provider.
// This method can only be called on the file thread.
@@ -108,7 +108,7 @@ class SandboxMountPointProvider
FileSystemType type,
bool create) const;
- virtual FileSystemFileUtil* GetFileUtil();
+ virtual FileSystemFileUtil* GetFileUtil() OVERRIDE;
// Deletes the data on the origin and reports the amount of deleted data
// to the quota manager via |proxy|.
diff --git a/webkit/glue/media/buffered_data_source.h b/webkit/glue/media/buffered_data_source.h
index 7667e4c..b8da78e 100644
--- a/webkit/glue/media/buffered_data_source.h
+++ b/webkit/glue/media/buffered_data_source.h
@@ -38,26 +38,28 @@ class BufferedDataSource : public WebDataSource {
virtual ~BufferedDataSource();
// media::Filter implementation.
- virtual void set_host(media::FilterHost* host);
- virtual void Stop(const base::Closure& callback);
- virtual void SetPlaybackRate(float playback_rate);
+ virtual void set_host(media::FilterHost* host) OVERRIDE;
+ virtual void Stop(const base::Closure& callback) OVERRIDE;
+ virtual void SetPlaybackRate(float playback_rate) OVERRIDE;
// media::DataSource implementation.
// Called from demuxer thread.
- virtual void Read(int64 position, size_t size,
- uint8* data,
- const media::DataSource::ReadCallback& read_callback);
- virtual bool GetSize(int64* size_out);
- virtual bool IsStreaming();
- virtual void SetPreload(media::Preload preload);
- virtual void SetBitrate(int bitrate);
+ virtual void Read(
+ int64 position,
+ size_t size,
+ uint8* data,
+ const media::DataSource::ReadCallback& read_callback) OVERRIDE;
+ virtual bool GetSize(int64* size_out) OVERRIDE;
+ virtual bool IsStreaming() OVERRIDE;
+ virtual void SetPreload(media::Preload preload) OVERRIDE;
+ virtual void SetBitrate(int bitrate) OVERRIDE;
// webkit_glue::WebDataSource implementation.
virtual void Initialize(const std::string& url,
- const media::PipelineStatusCB& callback);
- virtual void CancelInitialize();
- virtual bool HasSingleOrigin();
- virtual void Abort();
+ const media::PipelineStatusCB& callback) OVERRIDE;
+ virtual void CancelInitialize() OVERRIDE;
+ virtual bool HasSingleOrigin() OVERRIDE;
+ virtual void Abort() OVERRIDE;
protected:
// A factory method to create a BufferedResourceLoader based on the read
diff --git a/webkit/glue/media/simple_data_source.h b/webkit/glue/media/simple_data_source.h
index 77dc35c..fd3a282 100644
--- a/webkit/glue/media/simple_data_source.h
+++ b/webkit/glue/media/simple_data_source.h
@@ -48,16 +48,18 @@ class SimpleDataSource
virtual ~SimpleDataSource();
// media::Filter implementation.
- virtual void set_host(media::FilterHost* host);
- virtual void Stop(const base::Closure& callback);
+ virtual void set_host(media::FilterHost* host) OVERRIDE;
+ virtual void Stop(const base::Closure& callback) OVERRIDE;
// media::DataSource implementation.
- virtual void Read(int64 position, size_t size,
- uint8* data, const DataSource::ReadCallback& read_callback);
- virtual bool GetSize(int64* size_out);
- virtual bool IsStreaming();
- virtual void SetPreload(media::Preload preload);
- virtual void SetBitrate(int bitrate);
+ virtual void Read(int64 position,
+ size_t size,
+ uint8* data,
+ const DataSource::ReadCallback& read_callback) OVERRIDE;
+ virtual bool GetSize(int64* size_out) OVERRIDE;
+ virtual bool IsStreaming() OVERRIDE;
+ virtual void SetPreload(media::Preload preload) OVERRIDE;
+ virtual void SetBitrate(int bitrate) OVERRIDE;
// Used to inject a mock used for unittests.
virtual void SetURLLoaderForTest(WebKit::WebURLLoader* mock_loader);
@@ -94,10 +96,10 @@ class SimpleDataSource
// webkit_glue::WebDataSource implementation.
virtual void Initialize(const std::string& url,
- const media::PipelineStatusCB& callback);
- virtual void CancelInitialize();
- virtual bool HasSingleOrigin();
- virtual void Abort();
+ const media::PipelineStatusCB& callback) OVERRIDE;
+ virtual void CancelInitialize() OVERRIDE;
+ virtual bool HasSingleOrigin() OVERRIDE;
+ virtual void Abort() OVERRIDE;
private:
// Creates and starts the resource loading on the render thread.
diff --git a/webkit/glue/media/web_data_source_factory.h b/webkit/glue/media/web_data_source_factory.h
index 0e32621..da578b2 100644
--- a/webkit/glue/media/web_data_source_factory.h
+++ b/webkit/glue/media/web_data_source_factory.h
@@ -34,13 +34,13 @@ class WebDataSourceFactory : public media::AsyncDataSourceFactoryBase {
virtual ~WebDataSourceFactory();
// DataSourceFactory method.
- virtual media::DataSourceFactory* Clone() const;
+ virtual media::DataSourceFactory* Clone() const OVERRIDE;
protected:
// AsyncDataSourceFactoryBase methods.
- virtual bool AllowRequests() const;
+ virtual bool AllowRequests() const OVERRIDE;
virtual AsyncDataSourceFactoryBase::BuildRequest* CreateRequest(
- const std::string& url, const BuildCallback& callback);
+ const std::string& url, const BuildCallback& callback) OVERRIDE;
private:
class BuildRequest;
diff --git a/webkit/glue/webmediaplayer_impl.h b/webkit/glue/webmediaplayer_impl.h
index ac573d9..06a31fe 100644
--- a/webkit/glue/webmediaplayer_impl.h
+++ b/webkit/glue/webmediaplayer_impl.h
@@ -186,7 +186,7 @@ class WebMediaPlayerImpl
// even before this object gets destructed, so we need to know when
// |main_loop_| is being destroyed and we can stop posting repaint task
// to it.
- virtual void WillDestroyCurrentMessageLoop();
+ virtual void WillDestroyCurrentMessageLoop() OVERRIDE;
void Repaint();
diff --git a/webkit/plugins/npapi/plugin_stream_url.h b/webkit/plugins/npapi/plugin_stream_url.h
index 312f8de..4bf5232 100644
--- a/webkit/plugins/npapi/plugin_stream_url.h
+++ b/webkit/plugins/npapi/plugin_stream_url.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -32,26 +32,28 @@ class PluginStreamUrl : public PluginStream,
// Stop sending the stream to the client.
// Overrides the base Close so we can cancel our fetching the URL if
// it is still loading.
- virtual bool Close(NPReason reason);
+ virtual bool Close(NPReason reason) OVERRIDE;
- virtual WebPluginResourceClient* AsResourceClient();
+ virtual WebPluginResourceClient* AsResourceClient() OVERRIDE;
- virtual void CancelRequest();
+ virtual void CancelRequest() OVERRIDE;
//
// WebPluginResourceClient methods
//
- virtual void WillSendRequest(const GURL& url, int http_status_code);
+ virtual void WillSendRequest(const GURL& url, int http_status_code) OVERRIDE;
virtual void DidReceiveResponse(const std::string& mime_type,
const std::string& headers,
uint32 expected_length,
uint32 last_modified,
- bool request_is_seekable);
- virtual void DidReceiveData(const char* buffer, int length, int data_offset);
- virtual void DidFinishLoading();
- virtual void DidFail();
- virtual bool IsMultiByteResponseExpected();
- virtual int ResourceId();
+ bool request_is_seekable) OVERRIDE;
+ virtual void DidReceiveData(const char* buffer,
+ int length,
+ int data_offset) OVERRIDE;
+ virtual void DidFinishLoading() OVERRIDE;
+ virtual void DidFail() OVERRIDE;
+ virtual bool IsMultiByteResponseExpected() OVERRIDE;
+ virtual int ResourceId() OVERRIDE;
private:
GURL url_;
diff --git a/webkit/plugins/npapi/test/plugin_arguments_test.h b/webkit/plugins/npapi/test/plugin_arguments_test.h
index c2a0eaa..0904d49 100644
--- a/webkit/plugins/npapi/test/plugin_arguments_test.h
+++ b/webkit/plugins/npapi/test/plugin_arguments_test.h
@@ -1,10 +1,11 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
#ifndef WEBKIT_PLUGINS_NPAPI_TEST_PLUGIN_ARGUMENTS_TEST_H_
#define WEBKIT_PLUGINS_NPAPI_TEST_PLUGIN_ARGUMENTS_TEST_H_
+#include "base/compiler_specific.h"
#include "webkit/plugins/npapi/test/plugin_test.h"
namespace NPAPIClient {
@@ -32,10 +33,10 @@ class PluginArgumentsTest : public PluginTest {
// Initialize this PluginTest based on the arguments from NPP_New.
virtual NPError New(uint16 mode, int16 argc, const char* argn[],
- const char* argv[], NPSavedData* saved);
+ const char* argv[], NPSavedData* saved) OVERRIDE;
// NPAPI SetWindow handler.
- virtual NPError SetWindow(NPWindow* pNPWindow);
+ virtual NPError SetWindow(NPWindow* pNPWindow) OVERRIDE;
};
} // namespace NPAPIClient
diff --git a/webkit/plugins/npapi/test/plugin_delete_plugin_in_deallocate_test.h b/webkit/plugins/npapi/test/plugin_delete_plugin_in_deallocate_test.h
index 4dabd0e..af1ce74 100644
--- a/webkit/plugins/npapi/test/plugin_delete_plugin_in_deallocate_test.h
+++ b/webkit/plugins/npapi/test/plugin_delete_plugin_in_deallocate_test.h
@@ -4,6 +4,7 @@
#ifndef WEBKIT_PLUGINS_NPAPI_TEST_DELETE_PLUGIN_IN_DEALLOCATE_TEST_H_
#define WEBKIT_PLUGINS_NPAPI_TEST_DELETE_PLUGIN_IN_DEALLOCATE_TEST_H_
+#include "base/compiler_specific.h"
#include "webkit/plugins/npapi/test/plugin_test.h"
namespace NPAPIClient {
@@ -18,8 +19,8 @@ class DeletePluginInDeallocateTest : public PluginTest {
DeletePluginInDeallocateTest(NPP id, NPNetscapeFuncs* host_functions);
// NPAPI handlers.
- virtual NPError SetWindow(NPWindow* pNPWindow);
- virtual NPError Destroy();
+ virtual NPError SetWindow(NPWindow* pNPWindow) OVERRIDE;
+ virtual NPError Destroy() OVERRIDE;
NPObject* npobject_;
bool test_started_;
diff --git a/webkit/plugins/npapi/test/plugin_delete_plugin_in_stream_test.h b/webkit/plugins/npapi/test/plugin_delete_plugin_in_stream_test.h
index dca9de3..c6bf009 100644
--- a/webkit/plugins/npapi/test/plugin_delete_plugin_in_stream_test.h
+++ b/webkit/plugins/npapi/test/plugin_delete_plugin_in_stream_test.h
@@ -1,10 +1,11 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
#ifndef WEBKIT_PLUGINS_NPAPI_TEST_PLUGIN_DELETE_PLUGIN_IN_STREAM_TEST_H_
#define WEBKIT_PLUGINS_NPAPI_TEST_PLUGIN_DELETE_PLUGIN_IN_STREAM_TEST_H_
+#include "base/compiler_specific.h"
#include "webkit/plugins/npapi/test/plugin_test.h"
namespace NPAPIClient {
@@ -17,9 +18,9 @@ class DeletePluginInStreamTest : public PluginTest {
//
// NPAPI functions
//
- virtual NPError SetWindow(NPWindow* pNPWindow);
+ virtual NPError SetWindow(NPWindow* pNPWindow) OVERRIDE;
virtual NPError NewStream(NPMIMEType type, NPStream* stream,
- NPBool seekable, uint16* stype);
+ NPBool seekable, uint16* stype) OVERRIDE;
private:
bool test_started_;
std::string self_url_;
diff --git a/webkit/plugins/npapi/test/plugin_get_javascript_url2_test.h b/webkit/plugins/npapi/test/plugin_get_javascript_url2_test.h
index b5c398e..63491d6 100644
--- a/webkit/plugins/npapi/test/plugin_get_javascript_url2_test.h
+++ b/webkit/plugins/npapi/test/plugin_get_javascript_url2_test.h
@@ -1,10 +1,11 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
#ifndef WEBKIT_PLUGINS_NPAPI_PLUGINS_TEST_PLUGIN_GET_JAVASCRIPT_URL2_H_
#define WEBKIT_PLUGINS_NPAPI_PLUGINS_TEST_PLUGIN_GET_JAVASCRIPT_URL2_H_
+#include "base/compiler_specific.h"
#include "webkit/plugins/npapi/test/plugin_test.h"
namespace NPAPIClient {
@@ -19,14 +20,16 @@ class ExecuteGetJavascriptUrl2Test : public PluginTest {
//
// NPAPI functions
//
- virtual NPError SetWindow(NPWindow* pNPWindow);
+ virtual NPError SetWindow(NPWindow* pNPWindow) OVERRIDE;
virtual NPError NewStream(NPMIMEType type, NPStream* stream,
- NPBool seekable, uint16* stype);
- virtual int32 WriteReady(NPStream *stream);
+ NPBool seekable, uint16* stype) OVERRIDE;
+ virtual int32 WriteReady(NPStream *stream) OVERRIDE;
virtual int32 Write(NPStream *stream, int32 offset, int32 len,
- void *buffer);
- virtual NPError DestroyStream(NPStream *stream, NPError reason);
- virtual void URLNotify(const char* url, NPReason reason, void* data);
+ void *buffer) OVERRIDE;
+ virtual NPError DestroyStream(NPStream *stream, NPError reason) OVERRIDE;
+ virtual void URLNotify(const char* url,
+ NPReason reason,
+ void* data) OVERRIDE;
private:
bool test_started_;
diff --git a/webkit/plugins/npapi/test/plugin_get_javascript_url_test.h b/webkit/plugins/npapi/test/plugin_get_javascript_url_test.h
index 9aab3f9..f9f2bbd 100644
--- a/webkit/plugins/npapi/test/plugin_get_javascript_url_test.h
+++ b/webkit/plugins/npapi/test/plugin_get_javascript_url_test.h
@@ -1,10 +1,11 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
#ifndef WEBKIT_PLUGINS_NPAPI_PLUGINS_TEST_PLUGIN_GET_JAVASCRIPT_URL_H_
#define WEBKIT_PLUGINS_NPAPI_PLUGINS_TEST_PLUGIN_GET_JAVASCRIPT_URL_H_
+#include "base/compiler_specific.h"
#include "webkit/plugins/npapi/test/plugin_test.h"
namespace NPAPIClient {
@@ -18,14 +19,16 @@ class ExecuteGetJavascriptUrlTest : public PluginTest {
//
// NPAPI functions
//
- virtual NPError SetWindow(NPWindow* pNPWindow);
+ virtual NPError SetWindow(NPWindow* pNPWindow) OVERRIDE;
virtual NPError NewStream(NPMIMEType type, NPStream* stream,
- NPBool seekable, uint16* stype);
- virtual int32 WriteReady(NPStream *stream);
+ NPBool seekable, uint16* stype) OVERRIDE;
+ virtual int32 WriteReady(NPStream *stream) OVERRIDE;
virtual int32 Write(NPStream *stream, int32 offset, int32 len,
- void *buffer);
- virtual NPError DestroyStream(NPStream *stream, NPError reason);
- virtual void URLNotify(const char* url, NPReason reason, void* data);
+ void *buffer) OVERRIDE;
+ virtual NPError DestroyStream(NPStream *stream, NPError reason) OVERRIDE;
+ virtual void URLNotify(const char* url,
+ NPReason reason,
+ void* data) OVERRIDE;
private:
#if defined(OS_WIN)
diff --git a/webkit/plugins/npapi/test/plugin_geturl_test.h b/webkit/plugins/npapi/test/plugin_geturl_test.h
index 1e7cc9b..c7a9800 100644
--- a/webkit/plugins/npapi/test/plugin_geturl_test.h
+++ b/webkit/plugins/npapi/test/plugin_geturl_test.h
@@ -7,6 +7,7 @@
#include <stdio.h>
+#include "base/compiler_specific.h"
#include "webkit/plugins/npapi/test/plugin_test.h"
namespace NPAPIClient {
@@ -27,18 +28,19 @@ class PluginGetURLTest : public PluginTest {
// NPAPI functions
//
virtual NPError New(uint16 mode, int16 argc, const char* argn[],
- const char* argv[], NPSavedData* saved);
- virtual NPError SetWindow(NPWindow* pNPWindow);
+ const char* argv[], NPSavedData* saved) OVERRIDE;
+ virtual NPError SetWindow(NPWindow* pNPWindow) OVERRIDE;
virtual NPError NewStream(NPMIMEType type, NPStream* stream,
- NPBool seekable, uint16* stype);
- virtual int32 WriteReady(NPStream *stream);
+ NPBool seekable, uint16* stype) OVERRIDE;
+ virtual int32 WriteReady(NPStream *stream) OVERRIDE;
virtual int32 Write(NPStream *stream, int32 offset, int32 len,
- void *buffer);
- virtual NPError DestroyStream(NPStream *stream, NPError reason);
- virtual void StreamAsFile(NPStream* stream, const char* fname);
- virtual void URLNotify(const char* url, NPReason reason, void* data);
+ void *buffer) OVERRIDE;
+ virtual NPError DestroyStream(NPStream *stream, NPError reason) OVERRIDE;
+ virtual void StreamAsFile(NPStream* stream, const char* fname) OVERRIDE;
+ virtual void URLNotify(const char* url, NPReason reason,
+ void* data) OVERRIDE;
virtual void URLRedirectNotify(const char* url, int32_t status,
- void* notify_data);
+ void* notify_data) OVERRIDE;
private:
bool tests_started_;
diff --git a/webkit/plugins/npapi/test/plugin_javascript_open_popup.h b/webkit/plugins/npapi/test/plugin_javascript_open_popup.h
index 6381d25..b21cf27 100644
--- a/webkit/plugins/npapi/test/plugin_javascript_open_popup.h
+++ b/webkit/plugins/npapi/test/plugin_javascript_open_popup.h
@@ -1,10 +1,11 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
#ifndef WEBKIT_PLUGINS_NPAPI_TEST_PLUGIN_JAVASCRIPT_OPEN_POPUP_H_
#define WEBKIT_PLUGINS_NPAPI_TEST_PLUGIN_JAVASCRIPT_OPEN_POPUP_H_
+#include "base/compiler_specific.h"
#include "webkit/plugins/npapi/test/plugin_test.h"
namespace NPAPIClient {
@@ -18,7 +19,7 @@ class ExecuteJavascriptOpenPopupWithPluginTest : public PluginTest {
ExecuteJavascriptOpenPopupWithPluginTest(
NPP id, NPNetscapeFuncs *host_functions);
// NPAPI SetWindow handler.
- virtual NPError SetWindow(NPWindow* window);
+ virtual NPError SetWindow(NPWindow* window) OVERRIDE;
private:
bool popup_window_test_started_;
@@ -31,7 +32,7 @@ class ExecuteJavascriptPopupWindowTargetPluginTest : public PluginTest {
ExecuteJavascriptPopupWindowTargetPluginTest(
NPP id, NPNetscapeFuncs *host_functions);
// NPAPI SetWindow handler.
- virtual NPError SetWindow(NPWindow* window);
+ virtual NPError SetWindow(NPWindow* window) OVERRIDE;
private:
// Do a platform-specific validation of the passed-in |window|.
diff --git a/webkit/plugins/npapi/test/plugin_new_fails_test.h b/webkit/plugins/npapi/test/plugin_new_fails_test.h
index 334323e..d321a91 100644
--- a/webkit/plugins/npapi/test/plugin_new_fails_test.h
+++ b/webkit/plugins/npapi/test/plugin_new_fails_test.h
@@ -1,10 +1,11 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
#ifndef WEBKIT_PLUGINS_NPAPI_TEST_PLUGIN_PLUGIN_NEW_FAILS_TEST_H_
#define WEBKIT_PLUGINS_NPAPI_TEST_PLUGIN_PLUGIN_NEW_FAILS_TEST_H_
+#include "base/compiler_specific.h"
#include "webkit/plugins/npapi/test/plugin_test.h"
namespace NPAPIClient {
@@ -13,7 +14,7 @@ class NewFailsTest : public PluginTest {
public:
NewFailsTest(NPP id, NPNetscapeFuncs *host_functions);
virtual NPError New(uint16 mode, int16 argc, const char* argn[],
- const char* argv[], NPSavedData* saved);
+ const char* argv[], NPSavedData* saved) OVERRIDE;
};
} // namespace NPAPIClient
diff --git a/webkit/plugins/npapi/test/plugin_npobject_identity_test.h b/webkit/plugins/npapi/test/plugin_npobject_identity_test.h
index 9841e88..93b2e78 100644
--- a/webkit/plugins/npapi/test/plugin_npobject_identity_test.h
+++ b/webkit/plugins/npapi/test/plugin_npobject_identity_test.h
@@ -18,7 +18,7 @@ class NPObjectIdentityTest : public PluginTest {
NPObjectIdentityTest(NPP id, NPNetscapeFuncs *host_functions);
// NPAPI SetWindow handler.
- virtual NPError SetWindow(NPWindow* pNPWindow);
+ virtual NPError SetWindow(NPWindow* pNPWindow) OVERRIDE;
};
} // namespace NPAPIClient
diff --git a/webkit/plugins/npapi/test/plugin_npobject_lifetime_test.h b/webkit/plugins/npapi/test/plugin_npobject_lifetime_test.h
index 8365b9b..9bbfee2 100644
--- a/webkit/plugins/npapi/test/plugin_npobject_lifetime_test.h
+++ b/webkit/plugins/npapi/test/plugin_npobject_lifetime_test.h
@@ -1,10 +1,11 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
#ifndef WEBKIT_PLUGINS_NPAPI_TEST_PLUGIN_NPOBJECT_LIFETIME_TEST_H_
#define WEBKIT_PLUGINS_NPAPI_TEST_PLUGIN_NPOBJECT_LIFETIME_TEST_H_
+#include "base/compiler_specific.h"
#include "build/build_config.h"
#include "webkit/plugins/npapi/test/plugin_test.h"
@@ -20,9 +21,11 @@ class NPObjectLifetimeTest : public PluginTest {
NPObjectLifetimeTest(NPP id, NPNetscapeFuncs *host_functions);
// NPAPI SetWindow handler.
- virtual NPError SetWindow(NPWindow* pNPWindow);
+ virtual NPError SetWindow(NPWindow* pNPWindow) OVERRIDE;
- virtual void URLNotify(const char* url, NPReason reason, void* data);
+ virtual void URLNotify(const char* url,
+ NPReason reason,
+ void* data) OVERRIDE;
protected:
NPObject* other_plugin_instance_object_;
@@ -44,7 +47,7 @@ class NPObjectLifetimeTestInstance2 : public PluginTest {
virtual ~NPObjectLifetimeTestInstance2();
// NPAPI SetWindow handler.
- virtual NPError SetWindow(NPWindow* pNPWindow);
+ virtual NPError SetWindow(NPWindow* pNPWindow) OVERRIDE;
protected:
static NPObject* plugin_instance_object_;
friend class NPObjectLifetimeTest;
@@ -61,7 +64,7 @@ class NPObjectDeletePluginInNPN_Evaluate : public PluginTest {
virtual ~NPObjectDeletePluginInNPN_Evaluate();
// NPAPI SetWindow handler.
- virtual NPError SetWindow(NPWindow* pNPWindow);
+ virtual NPError SetWindow(NPWindow* pNPWindow) OVERRIDE;
protected:
NPObject* plugin_instance_object_;
diff --git a/webkit/plugins/npapi/test/plugin_npobject_proxy_test.h b/webkit/plugins/npapi/test/plugin_npobject_proxy_test.h
index 8585d0f..2f66dad 100644
--- a/webkit/plugins/npapi/test/plugin_npobject_proxy_test.h
+++ b/webkit/plugins/npapi/test/plugin_npobject_proxy_test.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -19,7 +19,7 @@ class NPObjectProxyTest : public PluginTest {
NPObjectProxyTest(NPP id, NPNetscapeFuncs *host_functions);
// NPAPI SetWindow handler.
- virtual NPError SetWindow(NPWindow* pNPWindow);
+ virtual NPError SetWindow(NPWindow* pNPWindow) OVERRIDE;
};
} // namespace NPAPIClient
diff --git a/webkit/plugins/npapi/test/plugin_private_test.h b/webkit/plugins/npapi/test/plugin_private_test.h
index 9079a11..2122c73 100644
--- a/webkit/plugins/npapi/test/plugin_private_test.h
+++ b/webkit/plugins/npapi/test/plugin_private_test.h
@@ -1,10 +1,11 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
#ifndef WEBKIT_PLUGINS_NPAPI_TEST_PLUGIN_PRIVATE_TEST_H_
#define WEBKIT_PLUGINS_NPAPI_TEST_PLUGIN_PRIVATE_TEST_H_
+#include "base/compiler_specific.h"
#include "webkit/plugins/npapi/test/plugin_test.h"
namespace NPAPIClient {
@@ -17,7 +18,7 @@ class PrivateTest : public PluginTest {
// Initialize this PluginTest based on the arguments from NPP_New.
virtual NPError New(uint16 mode, int16 argc, const char* argn[],
- const char* argv[], NPSavedData* saved);
+ const char* argv[], NPSavedData* saved) OVERRIDE;
};
} // namespace NPAPIClient
diff --git a/webkit/plugins/npapi/test/plugin_schedule_timer_test.h b/webkit/plugins/npapi/test/plugin_schedule_timer_test.h
index 13ed593..7486097 100644
--- a/webkit/plugins/npapi/test/plugin_schedule_timer_test.h
+++ b/webkit/plugins/npapi/test/plugin_schedule_timer_test.h
@@ -1,10 +1,11 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
#ifndef WEBKIT_PLUGINS_NPAPI_TEST_PLUGIN_SCHEDULE_TIMER_TEST_H
#define WEBKIT_PLUGINS_NPAPI_TEST_PLUGIN_SCHEDULE_TIMER_TEST_H
+#include "base/compiler_specific.h"
#include "base/time.h"
#include "webkit/plugins/npapi/test/plugin_test.h"
@@ -17,7 +18,7 @@ class ScheduleTimerTest : public PluginTest {
ScheduleTimerTest(NPP id, NPNetscapeFuncs *host_functions);
virtual NPError New(uint16 mode, int16 argc, const char* argn[],
- const char* argv[], NPSavedData* saved);
+ const char* argv[], NPSavedData* saved) OVERRIDE;
void OnTimer(uint32 timer_id);
diff --git a/webkit/plugins/npapi/test/plugin_setup_test.h b/webkit/plugins/npapi/test/plugin_setup_test.h
index 709b3b1..f4279c2 100644
--- a/webkit/plugins/npapi/test/plugin_setup_test.h
+++ b/webkit/plugins/npapi/test/plugin_setup_test.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -16,7 +16,7 @@ class PluginSetupTest : public PluginTest {
PluginSetupTest(NPP id, NPNetscapeFuncs *host_functions);
// NPAPI SetWindow handler.
- virtual NPError SetWindow(NPWindow* pNPWindow);
+ virtual NPError SetWindow(NPWindow* pNPWindow) OVERRIDE;
};
} // namespace NPAPIClient
diff --git a/webkit/plugins/npapi/test/plugin_thread_async_call_test.h b/webkit/plugins/npapi/test/plugin_thread_async_call_test.h
index 6962276..60a6bb6 100644
--- a/webkit/plugins/npapi/test/plugin_thread_async_call_test.h
+++ b/webkit/plugins/npapi/test/plugin_thread_async_call_test.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -21,9 +21,9 @@ class PluginThreadAsyncCallTest : public PluginTest {
virtual ~PluginThreadAsyncCallTest();
virtual NPError New(uint16 mode, int16 argc, const char* argn[],
- const char* argv[], NPSavedData* saved);
+ const char* argv[], NPSavedData* saved) OVERRIDE;
- virtual NPError Destroy();
+ virtual NPError Destroy() OVERRIDE;
void AsyncCall();
void OnCallSucceeded();
diff --git a/webkit/plugins/npapi/test/plugin_window_size_test.h b/webkit/plugins/npapi/test/plugin_window_size_test.h
index 5a49479..f52247e 100644
--- a/webkit/plugins/npapi/test/plugin_window_size_test.h
+++ b/webkit/plugins/npapi/test/plugin_window_size_test.h
@@ -1,10 +1,11 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
#ifndef WEBKIT_PLUGINS_NPAPI_TEST_PLUGIN_WINDOW_SIZE_TEST_H_
#define WEBKIT_PLUGINS_NPAPI_TEST_PLUGIN_WINDOW_SIZE_TEST_H_
+#include "base/compiler_specific.h"
#include "webkit/plugins/npapi/test/plugin_test.h"
namespace NPAPIClient {
@@ -16,7 +17,7 @@ class PluginWindowSizeTest : public PluginTest {
// Constructor.
PluginWindowSizeTest(NPP id, NPNetscapeFuncs *host_functions);
// NPAPI SetWindow handler
- virtual NPError SetWindow(NPWindow* pNPWindow);
+ virtual NPError SetWindow(NPWindow* pNPWindow) OVERRIDE;
};
} // namespace NPAPIClient
diff --git a/webkit/plugins/npapi/test/plugin_windowless_test.h b/webkit/plugins/npapi/test/plugin_windowless_test.h
index f5f6c7b..fdf54e9 100644
--- a/webkit/plugins/npapi/test/plugin_windowless_test.h
+++ b/webkit/plugins/npapi/test/plugin_windowless_test.h
@@ -17,10 +17,10 @@ class WindowlessPluginTest : public PluginTest {
WindowlessPluginTest(NPP id, NPNetscapeFuncs *host_functions);
// These tests run in windowless plugin mode.
- virtual bool IsWindowless() const;
+ virtual bool IsWindowless() const OVERRIDE;
// NPAPI HandleEvent handler
- virtual int16 HandleEvent(void* event);
+ virtual int16 HandleEvent(void* event) OVERRIDE;
protected:
NPError ExecuteScript(NPNetscapeFuncs* browser, NPP id,
diff --git a/webkit/plugins/npapi/webplugin_delegate_impl.h b/webkit/plugins/npapi/webplugin_delegate_impl.h
index 0a2fb75..a533a1a 100644
--- a/webkit/plugins/npapi/webplugin_delegate_impl.h
+++ b/webkit/plugins/npapi/webplugin_delegate_impl.h
@@ -107,35 +107,36 @@ class WebPluginDelegateImpl : public WebPluginDelegate {
const std::vector<std::string>& arg_names,
const std::vector<std::string>& arg_values,
WebPlugin* plugin,
- bool load_manually);
- virtual void PluginDestroyed();
+ bool load_manually) OVERRIDE;
+ virtual void PluginDestroyed() OVERRIDE;
virtual void UpdateGeometry(const gfx::Rect& window_rect,
- const gfx::Rect& clip_rect);
- virtual void Paint(WebKit::WebCanvas* canvas, const gfx::Rect& rect);
- virtual void SetFocus(bool focused);
+ const gfx::Rect& clip_rect) OVERRIDE;
+ virtual void Paint(WebKit::WebCanvas* canvas, const gfx::Rect& rect) OVERRIDE;
+ virtual void SetFocus(bool focused) OVERRIDE;
virtual bool HandleInputEvent(const WebKit::WebInputEvent& event,
- WebKit::WebCursorInfo* cursor_info);
- virtual NPObject* GetPluginScriptableObject();
- virtual bool GetFormValue(string16* value);
- virtual void DidFinishLoadWithReason(
- const GURL& url, NPReason reason, int notify_id);
- virtual int GetProcessId();
+ WebKit::WebCursorInfo* cursor_info) OVERRIDE;
+ virtual NPObject* GetPluginScriptableObject() OVERRIDE;
+ virtual bool GetFormValue(string16* value) OVERRIDE;
+ virtual void DidFinishLoadWithReason(const GURL& url,
+ NPReason reason,
+ int notify_id) OVERRIDE;
+ virtual int GetProcessId() OVERRIDE;
virtual void SendJavaScriptStream(const GURL& url,
const std::string& result,
bool success,
- int notify_id);
+ int notify_id) OVERRIDE;
virtual void DidReceiveManualResponse(const GURL& url,
const std::string& mime_type,
const std::string& headers,
uint32 expected_length,
- uint32 last_modified);
- virtual void DidReceiveManualData(const char* buffer, int length);
- virtual void DidFinishManualLoading();
- virtual void DidManualLoadFail();
+ uint32 last_modified) OVERRIDE;
+ virtual void DidReceiveManualData(const char* buffer, int length) OVERRIDE;
+ virtual void DidFinishManualLoading() OVERRIDE;
+ virtual void DidManualLoadFail() OVERRIDE;
virtual WebPluginResourceClient* CreateResourceClient(
- unsigned long resource_id, const GURL& url, int notify_id);
+ unsigned long resource_id, const GURL& url, int notify_id) OVERRIDE;
virtual WebPluginResourceClient* CreateSeekableResourceClient(
- unsigned long resource_id, int range_request_id);
+ unsigned long resource_id, int range_request_id) OVERRIDE;
// End of WebPluginDelegate implementation.
bool IsWindowless() const { return windowless_ ; }
diff --git a/webkit/plugins/npapi/webplugin_impl.h b/webkit/plugins/npapi/webplugin_impl.h
index 2664f43..a12d139 100644
--- a/webkit/plugins/npapi/webplugin_impl.h
+++ b/webkit/plugins/npapi/webplugin_impl.h
@@ -91,25 +91,26 @@ class WebPluginImpl : public WebPlugin,
const WebKit::WebURLError& error);
// WebPlugin implementation:
- virtual void SetWindow(gfx::PluginWindowHandle window);
- virtual void SetAcceptsInputEvents(bool accepts);
- virtual void WillDestroyWindow(gfx::PluginWindowHandle window);
+ virtual void SetWindow(gfx::PluginWindowHandle window) OVERRIDE;
+ virtual void SetAcceptsInputEvents(bool accepts) OVERRIDE;
+ virtual void WillDestroyWindow(gfx::PluginWindowHandle window) OVERRIDE;
#if defined(OS_WIN)
void SetWindowlessPumpEvent(HANDLE pump_messages_event) { }
void ReparentPluginWindow(HWND window, HWND parent) { }
#endif
- virtual void CancelResource(unsigned long id);
- virtual void Invalidate();
- virtual void InvalidateRect(const gfx::Rect& rect);
- virtual NPObject* GetWindowScriptNPObject();
- virtual NPObject* GetPluginElement();
- virtual bool FindProxyForUrl(const GURL& url, std::string* proxy_list);
+ virtual void CancelResource(unsigned long id) OVERRIDE;
+ virtual void Invalidate() OVERRIDE;
+ virtual void InvalidateRect(const gfx::Rect& rect) OVERRIDE;
+ virtual NPObject* GetWindowScriptNPObject() OVERRIDE;
+ virtual NPObject* GetPluginElement() OVERRIDE;
+ virtual bool FindProxyForUrl(const GURL& url,
+ std::string* proxy_list) OVERRIDE;
virtual void SetCookie(const GURL& url,
const GURL& first_party_for_cookies,
- const std::string& cookie);
+ const std::string& cookie) OVERRIDE;
virtual std::string GetCookies(const GURL& url,
- const GURL& first_party_for_cookies);
- virtual void URLRedirectResponse(bool allow, int resource_id);
+ const GURL& first_party_for_cookies) OVERRIDE;
+ virtual void URLRedirectResponse(bool allow, int resource_id) OVERRIDE;
// Given a (maybe partial) url, completes using the base url.
GURL CompleteURL(const char* url);
@@ -203,17 +204,19 @@ class WebPluginImpl : public WebPlugin,
unsigned int len,
int notify_id,
bool popups_allowed,
- bool notify_redirects);
+ bool notify_redirects) OVERRIDE;
- virtual void CancelDocumentLoad();
+ virtual void CancelDocumentLoad() OVERRIDE;
- virtual void InitiateHTTPRangeRequest(
- const char* url, const char* range_info, int pending_request_id);
+ virtual void InitiateHTTPRangeRequest(const char* url,
+ const char* range_info,
+ int pending_request_id) OVERRIDE;
- virtual void SetDeferResourceLoading(unsigned long resource_id, bool defer);
+ virtual void SetDeferResourceLoading(unsigned long resource_id,
+ bool defer) OVERRIDE;
// Ignore in-process plugins mode for this flag.
- virtual bool IsOffTheRecord();
+ virtual bool IsOffTheRecord() OVERRIDE;
// Handles HTTP multipart responses, i.e. responses received with a HTTP
// status code of 206.
diff --git a/webkit/quota/mock_special_storage_policy.h b/webkit/quota/mock_special_storage_policy.h
index 6f0ec13..c3b5d85 100644
--- a/webkit/quota/mock_special_storage_policy.h
+++ b/webkit/quota/mock_special_storage_policy.h
@@ -7,6 +7,7 @@
#include <set>
#include <string>
+
#include "googleurl/src/gurl.h"
#include "webkit/quota/special_storage_policy.h"
@@ -17,11 +18,11 @@ class MockSpecialStoragePolicy : public quota::SpecialStoragePolicy {
MockSpecialStoragePolicy();
virtual ~MockSpecialStoragePolicy();
- virtual bool IsStorageProtected(const GURL& origin);
- virtual bool IsStorageUnlimited(const GURL& origin);
- virtual bool IsStorageSessionOnly(const GURL& origin);
- virtual bool IsFileHandler(const std::string& extension_id);
- virtual bool HasSessionOnlyOrigins();
+ virtual bool IsStorageProtected(const GURL& origin) OVERRIDE;
+ virtual bool IsStorageUnlimited(const GURL& origin) OVERRIDE;
+ virtual bool IsStorageSessionOnly(const GURL& origin) OVERRIDE;
+ virtual bool IsFileHandler(const std::string& extension_id) OVERRIDE;
+ virtual bool HasSessionOnlyOrigins() OVERRIDE;
void AddProtected(const GURL& origin) {
protected_.insert(origin);
diff --git a/webkit/support/simple_database_system.h b/webkit/support/simple_database_system.h
index b15cb48..05f8189 100644
--- a/webkit/support/simple_database_system.h
+++ b/webkit/support/simple_database_system.h
@@ -63,9 +63,10 @@ class SimpleDatabaseSystem : public webkit_database::DatabaseTracker::Observer,
// DatabaseTracker::Observer implementation
virtual void OnDatabaseSizeChanged(const string16& origin_identifier,
const string16& database_name,
- int64 database_size);
- virtual void OnDatabaseScheduledForDeletion(const string16& origin_identifier,
- const string16& database_name);
+ int64 database_size) OVERRIDE;
+ virtual void OnDatabaseScheduledForDeletion(
+ const string16& origin_identifier,
+ const string16& database_name) OVERRIDE;
// Used by our public SQLite VFS methods, only called on the db_thread.
void VfsOpenFile(const string16& vfs_file_name, int desired_flags,
diff --git a/webkit/support/test_webplugin_page_delegate.h b/webkit/support/test_webplugin_page_delegate.h
index 94b571e..27d8ba3 100644
--- a/webkit/support/test_webplugin_page_delegate.h
+++ b/webkit/support/test_webplugin_page_delegate.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -19,13 +19,15 @@ class TestWebPluginPageDelegate : public webkit::npapi::WebPluginPageDelegate {
virtual webkit::npapi::WebPluginDelegate* CreatePluginDelegate(
const FilePath& file_path,
- const std::string& mime_type);
- virtual void CreatedPluginWindow(gfx::PluginWindowHandle handle) {}
- virtual void WillDestroyPluginWindow(gfx::PluginWindowHandle handle) {}
- virtual void DidMovePlugin(const webkit::npapi::WebPluginGeometry& move) {}
- virtual void DidStartLoadingForPlugin() {}
- virtual void DidStopLoadingForPlugin() {}
- virtual WebKit::WebCookieJar* GetCookieJar();
+ const std::string& mime_type) OVERRIDE;
+ virtual void CreatedPluginWindow(gfx::PluginWindowHandle handle) OVERRIDE {}
+ virtual void WillDestroyPluginWindow(
+ gfx::PluginWindowHandle handle) OVERRIDE {}
+ virtual void DidMovePlugin(
+ const webkit::npapi::WebPluginGeometry& move) OVERRIDE {}
+ virtual void DidStartLoadingForPlugin() OVERRIDE {}
+ virtual void DidStopLoadingForPlugin() OVERRIDE {}
+ virtual WebKit::WebCookieJar* GetCookieJar() OVERRIDE;
};
} // namespace webkit_support
diff --git a/webkit/tools/test_shell/accessibility_ui_element.h b/webkit/tools/test_shell/accessibility_ui_element.h
index 7786424..630464d 100644
--- a/webkit/tools/test_shell/accessibility_ui_element.h
+++ b/webkit/tools/test_shell/accessibility_ui_element.h
@@ -114,8 +114,8 @@ class RootAccessibilityUIElement : public AccessibilityUIElement {
Factory* factory);
virtual ~RootAccessibilityUIElement();
- virtual AccessibilityUIElement* GetChildAtIndex(unsigned index);
- virtual bool IsRoot() const;
+ virtual AccessibilityUIElement* GetChildAtIndex(unsigned index) OVERRIDE;
+ virtual bool IsRoot() const OVERRIDE;
};
@@ -129,7 +129,7 @@ class AccessibilityUIElementList : public AccessibilityUIElement::Factory {
void Clear();
virtual AccessibilityUIElement* Create(
- const WebKit::WebAccessibilityObject& object);
+ const WebKit::WebAccessibilityObject& object) OVERRIDE;
AccessibilityUIElement* CreateRoot(
const WebKit::WebAccessibilityObject& object);
diff --git a/webkit/tools/test_shell/simple_file_writer.h b/webkit/tools/test_shell/simple_file_writer.h
index 9ea2da5..f4f3772 100644
--- a/webkit/tools/test_shell/simple_file_writer.h
+++ b/webkit/tools/test_shell/simple_file_writer.h
@@ -38,10 +38,10 @@ class SimpleFileWriter : public fileapi::WebFileWriterBase,
protected:
// WebFileWriterBase overrides
- virtual void DoTruncate(const GURL& path, int64 offset);
+ virtual void DoTruncate(const GURL& path, int64 offset) OVERRIDE;
virtual void DoWrite(const GURL& path, const GURL& blob_url,
- int64 offset);
- virtual void DoCancel();
+ int64 offset) OVERRIDE;
+ virtual void DoCancel() OVERRIDE;
private:
class IOThreadProxy;
diff --git a/webkit/tools/test_shell/test_shell_request_context.h b/webkit/tools/test_shell/test_shell_request_context.h
index 0f987c6..0eb29cf 100644
--- a/webkit/tools/test_shell/test_shell_request_context.h
+++ b/webkit/tools/test_shell/test_shell_request_context.h
@@ -32,7 +32,7 @@ class TestShellRequestContext : public net::URLRequestContext {
net::HttpCache::Mode cache_mode,
bool no_proxy);
- virtual const std::string& GetUserAgent(const GURL& url) const;
+ virtual const std::string& GetUserAgent(const GURL& url) const OVERRIDE;
webkit_blob::BlobStorageController* blob_storage_controller() const {
return blob_storage_controller_.get();
diff --git a/webkit/tools/test_shell/test_shell_test.h b/webkit/tools/test_shell/test_shell_test.h
index 48dc8f93..852d8e8 100644
--- a/webkit/tools/test_shell/test_shell_test.h
+++ b/webkit/tools/test_shell/test_shell_test.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2006-2008 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -13,9 +13,9 @@
#include <string>
#include "base/file_path.h"
+#include "testing/gtest/include/gtest/gtest.h"
#include "webkit/glue/window_open_disposition.h"
#include "webkit/tools/test_shell/test_shell.h"
-#include "testing/gtest/include/gtest/gtest.h"
class TestShellTest : public testing::Test {
protected:
@@ -23,8 +23,8 @@ class TestShellTest : public testing::Test {
GURL GetTestURL(const FilePath& test_case_path,
const std::string& test_case);
- virtual void SetUp();
- virtual void TearDown();
+ virtual void SetUp() OVERRIDE;
+ virtual void TearDown() OVERRIDE;
// Don't refactor away; some unittests override this!
virtual void CreateEmptyWindow();
diff --git a/webkit/tools/test_shell/test_shell_webmimeregistry_impl.h b/webkit/tools/test_shell/test_shell_webmimeregistry_impl.h
index 9ebf201..2c8ad6c 100644
--- a/webkit/tools/test_shell/test_shell_webmimeregistry_impl.h
+++ b/webkit/tools/test_shell/test_shell_webmimeregistry_impl.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -8,6 +8,7 @@
#include <string>
#include <vector>
+#include "base/compiler_specific.h"
#include "base/hash_tables.h"
#include "webkit/glue/simple_webmimeregistry_impl.h"
@@ -25,7 +26,7 @@ class TestShellWebMimeRegistryImpl
// generated against ogg/vorbis/theora content we need to lock down how
// canPlayType() behaves when running layout tests.
virtual WebKit::WebMimeRegistry::SupportsType supportsMediaMIMEType(
- const WebKit::WebString&, const WebKit::WebString&);
+ const WebKit::WebString&, const WebKit::WebString&) OVERRIDE;
private:
bool IsSupportedMediaMimeType(const std::string& mime_type);
diff --git a/webkit/tools/test_shell/test_webview_delegate.h b/webkit/tools/test_shell/test_webview_delegate.h
index c1277b0..afad34c 100644
--- a/webkit/tools/test_shell/test_webview_delegate.h
+++ b/webkit/tools/test_shell/test_webview_delegate.h
@@ -239,16 +239,16 @@ class TestWebViewDelegate : public WebKit::WebViewClient,
// webkit::npapi::WebPluginPageDelegate
virtual webkit::npapi::WebPluginDelegate* CreatePluginDelegate(
const FilePath& url,
- const std::string& mime_type);
+ const std::string& mime_type) OVERRIDE;
virtual void CreatedPluginWindow(
- gfx::PluginWindowHandle handle);
+ gfx::PluginWindowHandle handle) OVERRIDE;
virtual void WillDestroyPluginWindow(
- gfx::PluginWindowHandle handle);
+ gfx::PluginWindowHandle handle) OVERRIDE;
virtual void DidMovePlugin(
- const webkit::npapi::WebPluginGeometry& move);
- virtual void DidStartLoadingForPlugin() {}
- virtual void DidStopLoadingForPlugin() {}
- virtual WebKit::WebCookieJar* GetCookieJar();
+ const webkit::npapi::WebPluginGeometry& move) OVERRIDE;
+ virtual void DidStartLoadingForPlugin() OVERRIDE {}
+ virtual void DidStopLoadingForPlugin() OVERRIDE {}
+ virtual WebKit::WebCookieJar* GetCookieJar() OVERRIDE;
TestWebViewDelegate(TestShell* shell);
virtual ~TestWebViewDelegate();
diff --git a/webkit/appcache/appcache_interceptor.h b/webkit/appcache/appcache_interceptor.h
index 423fd65..9f6759a 100644
--- a/webkit/appcache/appcache_interceptor.h
+++ b/webkit/appcache/appcache_interceptor.h
@@ -43,11 +43,13 @@ class APPCACHE_EXPORT AppCacheInterceptor
static AppCacheInterceptor* GetInstance();
protected:
- // Overridde from net::URLRequest::Interceptor:
- virtual net::URLRequestJob* MaybeIntercept(net::URLRequest* request);
- virtual net::URLRequestJob* MaybeInterceptResponse(net::URLRequest* request);
- virtual net::URLRequestJob* MaybeInterceptRedirect(net::URLRequest* request,
- const GURL& location);
+ // Override from net::URLRequest::Interceptor:
+ virtual net::URLRequestJob* MaybeIntercept(net::URLRequest* request) OVERRIDE;
+ virtual net::URLRequestJob* MaybeInterceptResponse(
+ net::URLRequest* request) OVERRIDE;
+ virtual net::URLRequestJob* MaybeInterceptRedirect(
+ net::URLRequest* request,
+ const GURL& location) OVERRIDE;
private:
friend struct DefaultSingletonTraits<AppCacheInterceptor>;